Models — Django Stories v0.5.1 documentation

Django Stories v0.5.1 documentation

# Models

- Table of Contents
- index
  modules
  previous

# Models

class `stories.models.` `Story`(*args, **kwargs)

  A newspaper or magazine type story or document that was possibly also printed in a periodical.

  exception `DoesNotExist`
  exception `Story.` `MultipleObjectsReturned`
  `Story.` `author`

    Easy way to get a combination of authors without having to worry which fields are set (author/one-off author)

  `Story.` `authors`
  `Story.` `categories`
  `Story.` `comments_frozen`

    Simplified way to get the comment status == frozen

  `Story.` `get_absolute_url`(*moreargs, **morekwargs)
  `Story.` `get_comment_status_display`(*moreargs, **morekwargs)
  `Story.` `get_next_by_modified_date`(*moreargs, **morekwargs)
  `Story.` `get_origin_display`(*moreargs, **morekwargs)
  `Story.` `get_previous_by_modified_date`(*moreargs, **morekwargs)
  `Story.` `get_related_content_type`(content_type)

    Get all related items of the specified content type

  `Story.` `get_relation_type`(relation_type)

    Get all relations of the specified relation type

  `Story.` `get_status_display`(*moreargs, **morekwargs)
  `Story.` `paragraphs`

    Return the paragraphs as a list

  `Story.` `primary_category`
  `Story.` `site`
  `Story.` `storyrelation_set`